# JoBase
**Fast Python Game Library**

[![](https://img.shields.io/github/commit-activity/m/jobase/jobase?label=Commit%20activity)](https://pypi.org/project/jobase)
[![](https://github.com/Grey41/JoBase/actions/workflows/wheels.yml/badge.svg)](https://github.com/Grey41/JoBase/actions/workflows/wheels.yml)

JoBase is a blazingly fast Python game library for beginner coders.
It is written in pure C and uses the OpenGL library.

Please visit [jobase.org](https://jobase.org) for tutorials and documentation.
If you find any problems or have any questions, please contact us at [hello@jobase.org](mailto:hello@jobase.org) or [raise an issue](https://github.com/JoBase/JoBase/issues/new) on GitHub.
